==> jaguar_auth_mongo-0.1.2.tar.gz: lib/src/auth_mongo.dart <==
// Copyright (c) 2017, teja. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:async';
import 'package:mongo_dart/mongo_dart.dart';
import 'package:jaguar/jaguar.dart';
import 'package:mongo_dart/mongo_dart.dart' as mgo;
import 'package:jaguar_auth/jaguar_auth.dart';
import 'package:jaguar_serializer/serializer.dart';
import 'package:jaguar_mongo/jaguar_mongo.dart';

class MgoUserManagerEmail<ModelType extends UserEmail>
    implements AuthModelManager {
  final String collection;

  final Serializer<ModelType> serializer;

  final Hasher hasher;

  MgoUserManagerEmail(this.serializer, {Hasher hasher, this.collection: 'user'})
      : hasher = hasher ?? const NoHasher();

  Future<ModelType> fetchModelByAuthorizationId(
      Context ctx, String userId) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.id(mgo.ObjectId.parse(userId)));
    return serializer.fromMap(map);
  }

  Future<ModelType> fetchModelByAuthenticationId(
      Context ctx, String email) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.eq("email", email));
    return serializer.fromMap(map);
  }

  /// Checks password [keyword] for given userId [authId] and
  /// returns the user [UserModel] if passwords match. Returns [null] if the
  /// password doesn't match or user with given authId is not found.
  Future<ModelType> authenticate(
      Context ctx, String userId, String password) async {
    ModelType model = await fetchModelByAuthenticationId(ctx, userId);

    if (model == null) {
      return null;
    }

    if (!hasher.verify(password, model.password)) {
      return null;
    }

    return model;
  }
}

class MgoUserManagerUsername<ModelType extends UserUsername>
    implements AuthModelManager {
  final String collection;

  final Serializer<ModelType> serializer;

  final Hasher hasher;

  MgoUserManagerUsername(this.serializer,
      {Hasher hasher, this.collection: 'user'})
      : hasher = hasher ?? const NoHasher();

  Future<ModelType> fetchModelByAuthorizationId(
      Context ctx, String userId) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.id(mgo.ObjectId.parse(userId)));
    return serializer.fromMap(map);
  }

  Future<ModelType> fetchModelByAuthenticationId(
      Context ctx, String username) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.eq("username", username));
    return serializer.fromMap(map);
  }

  /// Checks password [keyword] for given userId [authId] and
  /// returns the user [UserModel] if passwords match. Returns [null] if the
  /// password doesn't match or user with given authId is not found.
  Future<ModelType> authenticate(
      Context ctx, String userId, String password) async {
    ModelType model = await fetchModelByAuthenticationId(ctx, userId);

    if (model == null) {
      return null;
    }

    if (!hasher.verify(password, model.password)) {
      return null;
    }

    return model;
  }
}

class MgoUserManagerUsernameEmail<ModelType extends UserUsernameEmail>
    implements AuthModelManager {
  final String collection;

  final Serializer<ModelType> serializer;

  final Hasher hasher;

  MgoUserManagerUsernameEmail(this.serializer,
      {Hasher hasher, this.collection: 'user'})
      : hasher = hasher ?? const NoHasher();

  Future<ModelType> fetchModelByAuthorizationId(
      Context ctx, String userId) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.id(mgo.ObjectId.parse(userId)));
    return serializer.fromMap(map);
  }

  Future<ModelType> fetchModelByAuthenticationId(
      Context ctx, String username) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.eq("username", username));

    if (map != null) {
      return serializer.fromMap(map);
    }

    map = await col.findOne(mgo.where.eq("email", username));

    return serializer.fromMap(map);
  }

  /// Checks password [keyword] for given userId [authId] and
  /// returns the user [UserModel] if passwords match. Returns [null] if the
  /// password doesn't match or user with given authId is not found.
  Future<ModelType> authenticate(
      Context ctx, String userId, String password) async {
    ModelType model = await fetchModelByAuthenticationId(ctx, userId);

    if (model == null) {
      return null;
    }

    if (!hasher.verify(password, model.password)) {
      return null;
    }

    return model;
  }
}

==> jaguar_auth_mongo-0.2.0.tar.gz: lib/src/auth_mongo.dart <==
// Copyright (c) 2017, teja. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

library jaguar.auth.mongo;

import 'dart:async';
import 'package:mongo_dart/mongo_dart.dart';
import 'package:jaguar/jaguar.dart';
import 'package:mongo_dart/mongo_dart.dart' as mgo;
import 'package:jaguar_auth/jaguar_auth.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mongo/jaguar_mongo.dart';

class MgoUserManager<ModelType extends PasswordUser>
    implements AuthModelManager {
  final String collection;

  final List<String> fieldNames;

  final Serializer<ModelType> serializer;

  final Hasher hasher;

  MgoUserManager(this.serializer,
      {Hasher hasher,
      this.collection: 'user',
      this.fieldNames: const ['username']})
      : hasher = hasher ?? const NoHasher();

  Future<ModelType> fetchByAuthorizationId(Context ctx, String userId) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);
    Map map = await col.findOne(mgo.where.id(mgo.ObjectId.parse(userId)));
    return serializer.fromMap(map);
  }

  Future<ModelType> fetchByAuthenticationId(Context ctx, String authId) async {
    final Db db = ctx.getInput<Db>(MongoDb);
    final DbCollection col = db.collection(collection);

    for (String fieldName in fieldNames) {
      Map map = await col.findOne(mgo.where.eq(fieldName, authId));

      if (map == null) continue;

      return serializer.fromMap(map);
    }

    return null;
  }

  /// Checks password [keyword] for given userId [authId] and
  /// returns the user [UserModel] if passwords match. Returns [null] if the
  /// password doesn't match or user with given authId is not found.
  Future<ModelType> authenticate(
      Context ctx, String userId, String password) async {
    ModelType model = await fetchByAuthenticationId(ctx, userId);

    if (model == null) {
      return null;
    }

    if (!hasher.verify(password, model.password)) {
      return null;
    }

    return model;
  }
}
